==> firefox-3.5.10.source.tar.bz2: mozilla-1.9.1/testing/sisyphus/bin/clobber.sh <==
#!/bin/bash -e
# -*- Mode: Shell-script; tab-width: 4; indent-tabs-mode: nil; -*-
# ***** BEGIN LICENSE BLOCK *****
# Version: MPL 1.1/GPL 2.0/LGPL 2.1
#
# The contents of this file are subject to the Mozilla Public License Version
# 1.1 (the "License"); you may not use this file except in compliance with
# the License. You may obtain a copy of the License at
# http://www.mozilla.org/MPL/
#
# Software distributed under the License is distributed on an "AS IS" basis,
# WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
# for the specific language governing rights and limitations under the
# License.
#
# The Original Code is mozilla.org code.
#
# The Initial Developer of the Original Code is
# Mozilla Corporation.
# Portions created by the Initial Developer are Copyright (C) 2008.
# the Initial Developer. All Rights Reserved.
#
# Contributor(s):
#  Bob Clary <bob@bclary.com>
#
# Alternatively, the contents of this file may be used under the terms of
# either the GNU General Public License Version 2 or later (the "GPL"), or
# the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
# in which case the provisions of the GPL or the LGPL are applicable instead
# of those above. If you wish to allow use of your version of this file only
# under the terms of either the GPL or the LGPL, and not to allow others to
# use your version of this file under the terms of the MPL, indicate your
# decision by deleting the provisions above and replace them with the notice
# and other provisions required by the GPL or the LGPL. If you do not delete
# the provisions above, a recipient may use your version of this file under
# the terms of any one of the MPL, the GPL or the LGPL.
#
# ***** END LICENSE BLOCK *****

source $TEST_DIR/bin/library.sh
source $TEST_DIR/bin/set-build-env.sh $@

if [[ ! -e "$BUILDDIR" ]]; then
    echo "build directory \"$BUILDDIR\" doesn't exist, ignoring clobber"
    exit
fi 

case $product in
    firefox|thunderbird|fennec)

        if [[ ! -e "$executablepath" ]]; then
            echo "executable path $executablepath doesn't exist, ignoring clobber"
            exit
        fi 

        if ! $buildbash $bashlogin -c "cd $BUILDTREE/mozilla; make -f client.mk clobber" 2>&1; then
            echo "error during client.mk clobber" $LINENO
            echo "Forcing clobber" $LINENO
            rm -fR $BUILDTREE/mozilla/$product-$buildtype/
        fi
        ;;

    js)

        if [[ ! -e "$jsshellsourcepath" ]]; then
            echo "javascript shell source path $jsshellsourcepath doesn't exist, ignoring clobber"
            exit
        fi 
        if [[ -e "$BUILDTREE/mozilla/js/src/configure.in" ]]; then
            rm -f $BUILDTREE/mozilla/js/src/configure
        fi
        rm -fR $BUILDTREE/mozilla/js/src/*_*.OBJ
        ;;
esac

==> firefox-4.0.source.tar.bz2: mozilla-2.0/testing/sisyphus/bin/clobber.sh <==
#!/bin/bash -e
# -*- Mode: Shell-script; tab-width: 4; indent-tabs-mode: nil; -*-
# ***** BEGIN LICENSE BLOCK *****
# Version: MPL 1.1/GPL 2.0/LGPL 2.1
#
# The contents of this file are subject to the Mozilla Public License Version
# 1.1 (the "License"); you may not use this file except in compliance with
# the License. You may obtain a copy of the License at
# http://www.mozilla.org/MPL/
#
# Software distributed under the License is distributed on an "AS IS" basis,
# WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
# for the specific language governing rights and limitations under the
# License.
#
# The Original Code is mozilla.org code.
#
# The Initial Developer of the Original Code is
# Mozilla Corporation.
# Portions created by the Initial Developer are Copyright (C) 2008.
# the Initial Developer. All Rights Reserved.
#
# Contributor(s):
#  Bob Clary <bob@bclary.com>
#
# Alternatively, the contents of this file may be used under the terms of
# either the GNU General Public License Version 2 or later (the "GPL"), or
# the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
# in which case the provisions of the GPL or the LGPL are applicable instead
# of those above. If you wish to allow use of your version of this file only
# under the terms of either the GPL or the LGPL, and not to allow others to
# use your version of this file under the terms of the MPL, indicate your
# decision by deleting the provisions above and replace them with the notice
# and other provisions required by the GPL or the LGPL. If you do not delete
# the provisions above, a recipient may use your version of this file under
# the terms of any one of the MPL, the GPL or the LGPL.
#
# ***** END LICENSE BLOCK *****

source $TEST_DIR/bin/library.sh
source $TEST_DIR/bin/set-build-env.sh $@

if [[ ! -e "$BUILDDIR" ]]; then
    echo "build directory \"$BUILDDIR\" doesn't exist, ignoring clobber"
    exit
fi

case $product in
    firefox)

        if [[ ! -e "$executablepath" ]]; then
            echo "executable path $executablepath doesn't exist, ignoring clobber"
            exit
        fi

        if ! $buildbash $bashlogin -c "export PATH=\"$BUILDPATH\"; cd $BUILDTREE/mozilla; make -f client.mk clobber" 2>&1; then
            echo "error during client.mk clobber" $LINENO
            echo "Forcing clobber" $LINENO
            rm -fR $BUILDTREE/mozilla/$product-$buildtype/
        fi
        ;;

    js)

        if [[ ! -e "$jsshellsourcepath" ]]; then
            echo "javascript shell source path $jsshellsourcepath doesn't exist, ignoring clobber"
            exit
        fi
        if [[ -e "$BUILDTREE/mozilla/js/src/configure.in" ]]; then
            rm -f $BUILDTREE/mozilla/js/src/configure
        fi
        rm -fR $BUILDTREE/mozilla/js/src/*_*.OBJ
        ;;
esac
